wait

package
v0.18.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	ZONESTATE_CREATING         = "CREATING"
	ZONESTATE_CREATE_SUCCEEDED = "CREATE_SUCCEEDED"
	ZONESTATE_CREATE_FAILED    = "CREATE_FAILED"
	ZONESTATE_DELETING         = "DELETING"
	ZONESTATE_DELETE_SUCCEEDED = "DELETE_SUCCEEDED"
	ZONESTATE_DELETE_FAILED    = "DELETE_FAILED"
	ZONESTATE_UPDATING         = "UPDATING"
	ZONESTATE_UPDATE_SUCCEEDED = "UPDATE_SUCCEEDED"
	ZONESTATE_UPDATE_FAILED    = "UPDATE_FAILED"

	RECORDSETSTATE_CREATING         = "CREATING"
	RECORDSETSTATE_CREATE_SUCCEEDED = "CREATE_SUCCEEDED"
	RECORDSETSTATE_CREATE_FAILED    = "CREATE_FAILED"
	RECORDSETSTATE_DELETING         = "DELETING"
	RECORDSETSTATE_DELETE_SUCCEEDED = "DELETE_SUCCEEDED"
	RECORDSETSTATE_DELETE_FAILED    = "DELETE_FAILED"
	RECORDSETSTATE_UPDATING         = "UPDATING"
	RECORDSETSTATE_UPDATE_SUCCEEDED = "UPDATE_SUCCEEDED"
	RECORDSETSTATE_UPDATE_FAILED    = "UPDATE_FAILED"
)

Variables

This section is empty.

Functions

func CreateRecordSetWaitHandler

func CreateRecordSetWaitHandler(ctx context.Context, a dns.DefaultAPI, projectId, instanceId, rrSetId string) *wait.AsyncActionHandler[dns.RecordSetResponse]

CreateRecordWaitHandler will wait for recordset creation

func CreateZoneWaitHandler

func CreateZoneWaitHandler(ctx context.Context, a dns.DefaultAPI, projectId, instanceId string) *wait.AsyncActionHandler[dns.ZoneResponse]

CreateZoneWaitHandler will wait for zone creation

func DeleteRecordSetWaitHandler

func DeleteRecordSetWaitHandler(ctx context.Context, a dns.DefaultAPI, projectId, instanceId, rrSetId string) *wait.AsyncActionHandler[dns.RecordSetResponse]

DeleteRecordWaitHandler will wait for deletion returned interface is nil or *RecordSetResponse

func DeleteZoneWaitHandler

func DeleteZoneWaitHandler(ctx context.Context, a dns.DefaultAPI, projectId, instanceId string) *wait.AsyncActionHandler[dns.ZoneResponse]

DeleteZoneWaitHandler will wait for zone deletion returned interface is nil or *ZoneResponseZone

func PartialUpdateRecordSetWaitHandler

func PartialUpdateRecordSetWaitHandler(ctx context.Context, a dns.DefaultAPI, projectId, instanceId, rrSetId string) *wait.AsyncActionHandler[dns.RecordSetResponse]

UpdateRecordWaitHandler will wait for recordset update

func PartialUpdateZoneWaitHandler

func PartialUpdateZoneWaitHandler(ctx context.Context, a dns.DefaultAPI, projectId, instanceId string) *wait.AsyncActionHandler[dns.ZoneResponse]

PartialUpdateZoneWaitHandler will wait for zone update

Types

This section is empty.

Jump to