Documentation
¶
Overview ¶
Deprecated: Will be removed after 2026-09-30. Move to the packages generated for each available API version instead
Index ¶
- Constants
- func CreateGitInstanceWaitHandler(ctx context.Context, a APIClientInterface, projectId, instanceId string) *wait.AsyncActionHandler[git.Instance]deprecated
- func DeleteGitInstanceWaitHandler(ctx context.Context, a APIClientInterface, projectId, instanceId string) *wait.AsyncActionHandler[git.Instance]deprecated
- type APIClientInterface
Constants ¶
const ( // Deprecated: InstanceStateReady is deprecated and will be removed after 14th November 2025. Use [git.INSTANCESTATE_READY] instead. InstanceStateReady = "Ready" // Deprecated: InstanceStateCreating is deprecated and will be removed after 14th November 2025. Use [git.INSTANCESTATE_CREATING] instead. InstanceStateCreating = "Creating" // Deprecated: InstanceStateError is deprecated and will be removed after 14th November 2025. Use [git.INSTANCESTATE_ERROR] instead. InstanceStateError = "Error" )
Variables ¶
This section is empty.
Functions ¶
func CreateGitInstanceWaitHandler
deprecated
func CreateGitInstanceWaitHandler(ctx context.Context, a APIClientInterface, projectId, instanceId string) *wait.AsyncActionHandler[git.Instance]
Deprecated: Will be removed after 2026-09-30. Move to the packages generated for each available API version instead
func DeleteGitInstanceWaitHandler
deprecated
func DeleteGitInstanceWaitHandler(ctx context.Context, a APIClientInterface, projectId, instanceId string) *wait.AsyncActionHandler[git.Instance]
Deprecated: Will be removed after 2026-09-30. Move to the packages generated for each available API version instead
Types ¶
type APIClientInterface ¶
type APIClientInterface interface {
GetInstanceExecute(ctx context.Context, projectId string, instanceId string) (*git.Instance, error)
}
APIClientInterface Interfaces needed for tests Deprecated: Will be removed after 2026-09-30. Move to the packages generated for each available API version instead
Click to show internal directories.
Click to hide internal directories.