Documentation
¶
Index ¶
- Constants
- func CreateDremioUserWaitHandler(ctx context.Context, a dremio.DefaultAPI, ...) *wait.AsyncActionHandler[dremio.DremioUserResponse]
- func CreateDremioWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId string) *wait.AsyncActionHandler[dremio.DremioResponse]
- func DeleteDremioUserWaitHandler(ctx context.Context, a dremio.DefaultAPI, ...) *wait.AsyncActionHandler[dremio.DremioUserResponse]
- func DeleteDremioWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId string) *wait.AsyncActionHandler[dremio.DremioResponse]
- func UpdateDremioUserWaitHandler(ctx context.Context, a dremio.DefaultAPI, ...) *wait.AsyncActionHandler[dremio.DremioUserResponse]
- func UpdateDremioWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId string) *wait.AsyncActionHandler[dremio.DremioResponse]
Constants ¶
const ( // Deprecated: symbol is not used anymore, use the packages enum instead, will be removed 2026-12, use `go fix` for automatic fixing //go:fix inline DREMIOSTATE_ACTIVE = dremio.DREMIORESPONSESTATE_ACTIVE // Deprecated: symbol is not used anymore, use the packages enum instead, will be removed 2026-12, use `go fix` for automatic fixing //go:fix inline DREMIOSTATE_ERROR = dremio.DREMIORESPONSESTATE_ERROR // Deprecated: symbol is not used anymore, use the packages enum instead, will be removed 2026-12, use `go fix` for automatic fixing //go:fix inline DREMIOUSERSTATE_ACTIVE = dremio.DREMIOUSERRESPONSESTATE_ACTIVE // Deprecated: symbol is not used anymore, use the packages enum instead, will be removed 2026-12, use `go fix` for automatic fixing //go:fix inline DREMIOUSERSTATE_ERROR = dremio.DREMIOUSERRESPONSESTATE_ERROR )
Variables ¶
This section is empty.
Functions ¶
func CreateDremioUserWaitHandler ¶
func CreateDremioUserWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId, dremioUserId string) *wait.AsyncActionHandler[dremio.DremioUserResponse]
CreateDremioUserWaitHandler will wait for the creation of a Dremio user
func CreateDremioWaitHandler ¶
func CreateDremioWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId string) *wait.AsyncActionHandler[dremio.DremioResponse]
CreateDremioWaitHandler will wait for the creation of a Dremio instance
func DeleteDremioUserWaitHandler ¶
func DeleteDremioUserWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId, dremioUserId string) *wait.AsyncActionHandler[dremio.DremioUserResponse]
DeleteDremioUserWaitHandler will wait for a deletion of a Dremio user
func DeleteDremioWaitHandler ¶
func DeleteDremioWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId string) *wait.AsyncActionHandler[dremio.DremioResponse]
DeleteDremioWaitHandler will wait for the deletion of a Dremio instance
func UpdateDremioUserWaitHandler ¶
func UpdateDremioUserWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId, dremioUserId string) *wait.AsyncActionHandler[dremio.DremioUserResponse]
UpdateDremioUserWaitHandler will wait for an update to a Dremio user
func UpdateDremioWaitHandler ¶
func UpdateDremioWaitHandler(ctx context.Context, a dremio.DefaultAPI, projectId, regionId, dremioId string) *wait.AsyncActionHandler[dremio.DremioResponse]
UpdateDremioWaitHandler will wait an update of a Dremio instance
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.